betty.ancestry.enclosure module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.enclosure module

Data types to describe the relationships between places.

final class betty.ancestry.enclosure.Enclosure

  Bases: `ShorthandPluginBase`, `HasDate`, `HasCitations`, `Entity`

  The enclosure of one place by another.

  Enclosures describe the outer (``encloser`) and inner(``enclosee`) places, and their relationship.

  __init__(enclosee: Place | ToOneResolver[Place], encloser: Place | ToOneResolver[Place])
  enclosee

    The inner place.

  encloser

    The outer place.

  classmethod plugin_label_plural() → Localizable

    The human-readable entity type label, plural.